@@ -12,6 +12,10 @@ class SensorLibrary:
         device_class=SensorDeviceClass.BATTERY,
         native_unit_of_measurement=Units.PERCENTAGE,
     )
+    CONDUCTIVITY__CONDUCTIVITY = BaseSensorDescription(
+        device_class=SensorDeviceClass.CONDUCTIVITY,
+        native_unit_of_measurement=Units.CONDUCTIVITY,
+    )
     COUNT__NONE = BaseSensorDescription(
         device_class=SensorDeviceClass.COUNT,
         native_unit_of_measurement=None,
@@ -36,10 +40,18 @@ class SensorLibrary:
         device_class=SensorDeviceClass.DISTANCE,
         native_unit_of_measurement=Units.LENGTH_MILLIMETERS,
     )
+    DURATION__TIME_SECONDS = BaseSensorDescription(
+        device_class=SensorDeviceClass.DURATION,
+        native_unit_of_measurement=Units.TIME_SECONDS,
+    )
     ENERGY__ENERGY_KILO_WATT_HOUR = BaseSensorDescription(
         device_class=SensorDeviceClass.ENERGY,
         native_unit_of_measurement=Units.ENERGY_KILO_WATT_HOUR,
     )
+    FORMALDEHYDE__CONCENTRATION_MILLIGRAMS_PER_CUBIC_METER = BaseSensorDescription(
+        device_class=SensorDeviceClass.FORMALDEHYDE,
+        native_unit_of_measurement=Units.CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    )
     GAS__VOLUME_CUBIC_METERS = BaseSensorDescription(
         device_class=SensorDeviceClass.GAS,
         native_unit_of_measurement=Units.VOLUME_CUBIC_METERS,
@@ -116,9 +128,9 @@ class SensorLibrary:
         device_class=SensorDeviceClass.TEMPERATURE,
         native_unit_of_measurement=Units.TEMP_CELSIUS,
     )
-    TIME__TIME_SECONDS = BaseSensorDescription(
-        device_class=SensorDeviceClass.TIME,
-        native_unit_of_measurement=Units.TIME_SECONDS,
+    UV_INDEX__NONE = BaseSensorDescription(
+        device_class=SensorDeviceClass.UV_INDEX,
+        native_unit_of_measurement=None,
     )
     VOLATILE_ORGANIC_COMPOUNDS__CONCENTRATION_MICROGRAMS_PER_CUBIC_METER = (
         BaseSensorDescription(
